/**
 * @typedef {import('multiformats/cid').CIDVersion} CIDVersion
 * @typedef {import('ipfs-core-types').IPFS} IPFS
 * @typedef {import('ipfs-core-types/src/root').AddOptions} AddOptions
 * @typedef {import('ipfs-core-types/src/root').AddAllOptions} AddAllOptions
 * @typedef {import('ipfs-core-types/src/root').IPFSEntry} IPFSEntry
 * @typedef {import('ipfs-message-port-protocol/src/cid').EncodedCID} EncodedCID
 * @typedef {import('ipfs-core-types/src/utils').ImportCandidateStream} ImportCandidateStream
 * @typedef {import('ipfs-core-types/src/utils').ImportCandidate} ImportCandidate
 * @typedef {import('ipfs-core-types/src/root').AddResult} AddResult
 * @typedef {import('ipfs-message-port-protocol/src/root').EncodedAddInput} EncodedAddInput
 * @typedef {import('ipfs-message-port-protocol/src/root').EncodedAddAllInput} EncodedAddAllInput
 * @typedef {import('ipfs-message-port-protocol/src/root').EncodedFileContent} EncodedFileContent
 * @typedef {import('ipfs-message-port-protocol/src/root').EncodedIPFSEntry} EncodedIPFSEntry
 */
/**
 * @typedef {import('ipfs-message-port-protocol/src/core').RemoteCallback} RemoteCallback
 */
/**
 * @template T
 * @typedef {import('ipfs-message-port-protocol/src/core').RemoteIterable<T>} RemoteIterable
 */
/**
 * @typedef {object} AddAllInput
 * @property {EncodedAddAllInput} input
 * @property {RemoteCallback} [progressCallback]
 *
 * @typedef {object} AddInput
 * @property {EncodedAddInput} input
 * @property {RemoteCallback} [progressCallback]
 *
 * @typedef {AddInput & AddOptions} AddQuery
 * @typedef {AddAllInput & AddAllOptions} AddAllQuery
 */
export class CoreService {
    /**
     * @param {IPFS} ipfs
     */
    constructor(ipfs: IPFS);
    ipfs: import("ipfs-core-types").IPFS<any>;
    /**
     * @param {AddAllQuery} query
     */
    addAll(query: AddAllQuery): {
        data: import("ipfs-message-port-protocol/core").RemoteIterable<{
            cid: import("ipfs-message-port-protocol/cid").EncodedCID;
            size: number;
            path: string;
            mode?: number | undefined;
            mtime?: import("ipfs-unixfs/dist/src/types").Mtime | undefined;
        }>;
        transfer: Set<Transferable>;
    };
    /**
     * @param {AddQuery} query
     */
    add(query: AddQuery): Promise<{
        data: {
            cid: import("ipfs-message-port-protocol/cid").EncodedCID;
            size: number;
            path: string;
            mode?: number | undefined;
            mtime?: import("ipfs-unixfs/dist/src/types").Mtime | undefined;
        };
        transfer: Set<Transferable>;
    }>;
    /**
     * @typedef {object} CatQuery
     * @property {string|EncodedCID} path
     * @property {number} [offset]
     * @property {number} [length]
     * @property {number} [timeout]
     * @property {AbortSignal} [signal]
     *
     * @param {CatQuery} query
     */
    cat(query: {
        path: string | EncodedCID;
        offset?: number | undefined;
        length?: number | undefined;
        timeout?: number | undefined;
        signal?: AbortSignal | undefined;
    }): {
        data: import("ipfs-message-port-protocol/core").RemoteIterable<Uint8Array>;
        transfer: Set<Transferable>;
    };
    /**
     * @typedef {object} LsQuery
     * @property {string|EncodedCID} path
     * @property {boolean} [preload]
     * @property {boolean} [recursive]
     * @property {number} [timeout]
     * @property {AbortSignal} [signal]
     *
     * @param {LsQuery} query
     */
    ls(query: {
        path: string | EncodedCID;
        preload?: boolean | undefined;
        recursive?: boolean | undefined;
        timeout?: number | undefined;
        signal?: AbortSignal | undefined;
    }): {
        data: import("ipfs-message-port-protocol/core").RemoteIterable<{
            cid: import("ipfs-message-port-protocol/cid").EncodedCID;
            type: "dir" | "file";
            name: string;
            path: string;
            mode: number | undefined;
            mtime: import("ipfs-unixfs/dist/src/types").Mtime | undefined;
            size: number;
        }>;
        transfer: Set<Transferable>;
    };
}
export type CIDVersion = import('multiformats/cid').CIDVersion;
export type IPFS = import('ipfs-core-types').IPFS;
export type AddOptions = import('ipfs-core-types/src/root').AddOptions;
export type AddAllOptions = import('ipfs-core-types/src/root').AddAllOptions;
export type IPFSEntry = import('ipfs-core-types/src/root').IPFSEntry;
export type EncodedCID = import('ipfs-message-port-protocol/src/cid').EncodedCID;
export type ImportCandidateStream = import('ipfs-core-types/src/utils').ImportCandidateStream;
export type ImportCandidate = import('ipfs-core-types/src/utils').ImportCandidate;
export type AddResult = import('ipfs-core-types/src/root').AddResult;
export type EncodedAddInput = import('ipfs-message-port-protocol/src/root').EncodedAddInput;
export type EncodedAddAllInput = import('ipfs-message-port-protocol/src/root').EncodedAddAllInput;
export type EncodedFileContent = import('ipfs-message-port-protocol/src/root').EncodedFileContent;
export type EncodedIPFSEntry = import('ipfs-message-port-protocol/src/root').EncodedIPFSEntry;
export type RemoteCallback = import('ipfs-message-port-protocol/src/core').RemoteCallback;
export type RemoteIterable<T> = import('ipfs-message-port-protocol/src/core').RemoteIterable<T>;
export type AddAllInput = {
    input: EncodedAddAllInput;
    progressCallback?: import("ipfs-message-port-protocol/core").RemoteCallback | undefined;
};
export type AddInput = {
    input: EncodedAddInput;
    progressCallback?: import("ipfs-message-port-protocol/core").RemoteCallback | undefined;
};
export type AddQuery = AddInput & AddOptions;
export type AddAllQuery = AddAllInput & AddAllOptions;
//# sourceMappingURL=core.d.ts.map